#!/usr/bin/python2.5

import unittest

from unit.test_facebook import TestFacebookService
from unit.test_gravatar import TestGravatarService
from unit.test_linkedin import TestLinkedInService
from unit.test_twitter import TestTwitterService
from unit.test_hermes import TestHermes
from unit.test_friend import TestFriend
from unit.test_phonenumber import TestPhoneNumber

from integration.test_gravatar import IntegrationTestGravatarService
from integration.test_linkedinapi import IntegrationTestLinkedInApi
from integration.test_twitter import IntegrationTestTwitterService

if __name__ == '__main__':
    unittest.main()
